# phonespeak_api

PhonespeakApi - JavaScript client for phonespeak_api
PhoneSpeak API v2
This SDK is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: v2
- Package version: v2
- Build package: io.swagger.codegen.languages.JavascriptClientCodegen

## Installation

### For [Node.js](https://nodejs.org/)

#### npm

To publish the library as a [npm](https://www.npmjs.com/),
please follow the procedure in ["Publishing npm packages"](https://docs.npmjs.com/getting-started/publishing-npm-packages).

Then install it via:

```shell
npm install phonespeak_api --save
```

##### Local development

To use the library locally without publishing to a remote npm registry, first install the dependencies by changing 
into the directory containing `package.json` (and this README). Let's call this `JAVASCRIPT_CLIENT_DIR`. Then run:

```shell
npm install
```

Next, [link](https://docs.npmjs.com/cli/link) it globally in npm with the following, also from `JAVASCRIPT_CLIENT_DIR`:

```shell
npm link
```

Finally, switch to the directory you want to use your phonespeak_api from, and run:

```shell
npm link /path/to/<JAVASCRIPT_CLIENT_DIR>
```

You should now be able to `require('phonespeak_api')` in javascript files from the directory you ran the last 
command above from.

#### git
#
If the library is hosted at a git repository, e.g.
https://github.com/GIT_USER_ID/GIT_REPO_ID
then install it via:

```shell
    npm install GIT_USER_ID/GIT_REPO_ID --save
```

### For browser

The library also works in the browser environment via npm and [browserify](http://browserify.org/). After following
the above steps with Node.js and installing browserify with `npm install -g browserify`,
perform the following (assuming *main.js* is your entry file, that's to say your javascript file where you actually 
use this library):

```shell
browserify main.js > bundle.js
```

Then include *bundle.js* in the HTML pages.

### Webpack Configuration

Using Webpack you may encounter the following error: "Module not found: Error:
Cannot resolve module", most certainly you should disable AMD loader. Add/merge
the following section to your webpack config:

```javascript
module: {
  rules: [
    {
      parser: {
        amd: false
      }
    }
  ]
}
```

## Getting Started

Please follow the [installation](#installation) instruction and execute the following JS code:

```javascript
var PhonespeakApi = require('phonespeak_api');

var defaultClient = PhonespeakApi.ApiClient.instance;

// Configure API key authorization: Authorization
var Authorization = defaultClient.authentications['Authorization'];
Authorization.apiKey = "YOUR API KEY"
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//Authorization.apiKeyPrefix['Authorization'] = "Token"

var api = new PhonespeakApi.AccountApi()

var id = "id_example"; // {String} account id

var startDate = new Date("2013-10-20T19:20:30+01:00"); // {Date} start date

var endDate = new Date("2013-10-20T19:20:30+01:00"); // {Date} end date

var opts = { 
  'type': 56, // {Number} call type
  'size': 56, // {Number} page size
  'pageNum': 56 // {Number} page number
};

var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
api.accountCallUsage(id, startDate, endDate, opts, callback);

```

## Documentation for API Endpoints

All URIs are relative to *http://api-dev.phonespeak.com*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*PhonespeakApi.AccountApi* | [**accountCallUsage**](docs/AccountApi.md#accountCallUsage) | **GET** /client/Account/{id}/CallUsage | List of Call Usage
*PhonespeakApi.AccountApi* | [**accountCreate**](docs/AccountApi.md#accountCreate) | **POST** /client/Account | Create a single account
*PhonespeakApi.AccountApi* | [**accountCreateBillingContact**](docs/AccountApi.md#accountCreateBillingContact) | **POST** /client/Account/{id}/BillingContact | Create a single billing contact
*PhonespeakApi.AccountApi* | [**accountCreateCreditCard**](docs/AccountApi.md#accountCreateCreditCard) | **POST** /client/Account/{id}/CreditCard | Create credit card
*PhonespeakApi.AccountApi* | [**accountCreateInvoice**](docs/AccountApi.md#accountCreateInvoice) | **POST** /client/Account/{id}/Invoice | Create invoice
*PhonespeakApi.AccountApi* | [**accountCreateSession**](docs/AccountApi.md#accountCreateSession) | **POST** /client/Account/Session | 
*PhonespeakApi.AccountApi* | [**accountDelete**](docs/AccountApi.md#accountDelete) | **DELETE** /client/Account/{id} | Delete a single account
*PhonespeakApi.AccountApi* | [**accountDeleteBillingContact**](docs/AccountApi.md#accountDeleteBillingContact) | **DELETE** /client/Account/{id}/BillingContact/{contactId} | Delete billing contact
*PhonespeakApi.AccountApi* | [**accountDeleteCreditCard**](docs/AccountApi.md#accountDeleteCreditCard) | **DELETE** /client/Account/{id}/CreditCard/{creditCardId} | Delete credit card
*PhonespeakApi.AccountApi* | [**accountDeleteMusicOnHold**](docs/AccountApi.md#accountDeleteMusicOnHold) | **DELETE** /client/Account/{id}/MusicOnHold/{mohId} | Delete MusicOnHold
*PhonespeakApi.AccountApi* | [**accountDisableInternationalCall**](docs/AccountApi.md#accountDisableInternationalCall) | **DELETE** /client/Account/{id}/InternationalCall | Disable international call
*PhonespeakApi.AccountApi* | [**accountEnableInternationalCall**](docs/AccountApi.md#accountEnableInternationalCall) | **POST** /client/Account/{id}/InternationalCall | Enable international call
*PhonespeakApi.AccountApi* | [**accountGet**](docs/AccountApi.md#accountGet) | **GET** /client/Account/{id} | Retrieve a single account
*PhonespeakApi.AccountApi* | [**accountGetAvailableUserExtension**](docs/AccountApi.md#accountGetAvailableUserExtension) | **GET** /client/Account/{id}/Extension/Available | Update business hour
*PhonespeakApi.AccountApi* | [**accountGetBillingContact**](docs/AccountApi.md#accountGetBillingContact) | **GET** /client/Account/{id}/BillingContact/{contactId} | Retrieve billing contact details
*PhonespeakApi.AccountApi* | [**accountGetCreditCard**](docs/AccountApi.md#accountGetCreditCard) | **GET** /client/Account/{id}/CreditCard/{creditCardId} | Get credit card details
*PhonespeakApi.AccountApi* | [**accountGetInvoice**](docs/AccountApi.md#accountGetInvoice) | **GET** /client/Account/{id}/Invoice/{invoiceId} | Get invoice
*PhonespeakApi.AccountApi* | [**accountGetPhoneNumber**](docs/AccountApi.md#accountGetPhoneNumber) | **GET** /client/Account/{id}/PhoneNumber | Get Account&#39;s Phone Number
*PhonespeakApi.AccountApi* | [**accountGetPhoneNumberList**](docs/AccountApi.md#accountGetPhoneNumberList) | **GET** /client/Account/{id}/PhoneNumberList | Get Account&#39;s Phone Number (Manage Number)
*PhonespeakApi.AccountApi* | [**accountIsCreditCardExist**](docs/AccountApi.md#accountIsCreditCardExist) | **GET** /client/Account/{id}/CreditCard/Exist | Is Credit card exist
*PhonespeakApi.AccountApi* | [**accountListAccountPhoneNumber**](docs/AccountApi.md#accountListAccountPhoneNumber) | **GET** /client/Account/{id}/AccountPhoneNumber | List Phone Number
*PhonespeakApi.AccountApi* | [**accountListAllowedCountryCode**](docs/AccountApi.md#accountListAllowedCountryCode) | **GET** /client/Account/{id}/CallCountryCode | Get list of allowed country code
*PhonespeakApi.AccountApi* | [**accountListCreditCards**](docs/AccountApi.md#accountListCreditCards) | **GET** /client/Account/{id}/CreditCard | Get list of credit card
*PhonespeakApi.AccountApi* | [**accountListE911Addresses**](docs/AccountApi.md#accountListE911Addresses) | **GET** /client/Account/{id}/E911Address | Retrieve list of E911 address
*PhonespeakApi.AccountApi* | [**accountListInvoices**](docs/AccountApi.md#accountListInvoices) | **GET** /client/Account/{id}/Invoice | Get list of invoices.
*PhonespeakApi.AccountApi* | [**accountListMusicOnHold**](docs/AccountApi.md#accountListMusicOnHold) | **GET** /client/Account/{id}/MusicOnHold | Get list of MusicOnHolds
*PhonespeakApi.AccountApi* | [**accountListRateDeck**](docs/AccountApi.md#accountListRateDeck) | **GET** /client/Account/{id}/RateDeck | 
*PhonespeakApi.AccountApi* | [**accountTopupCallCredit**](docs/AccountApi.md#accountTopupCallCredit) | **PUT** /client/Account/{id}/CallCredit | Topup Call Credit
*PhonespeakApi.AccountApi* | [**accountUpdate**](docs/AccountApi.md#accountUpdate) | **PUT** /client/Account/{id} | Update account
*PhonespeakApi.AccountApi* | [**accountUpdateAllowedCountryCode**](docs/AccountApi.md#accountUpdateAllowedCountryCode) | **PUT** /client/Account/{id}/CallCountryCode | Add allowed country code
*PhonespeakApi.AccountApi* | [**accountUpdateBillingContact**](docs/AccountApi.md#accountUpdateBillingContact) | **PUT** /client/Account/{id}/BillingContact/{contactId} | Update billing contact
*PhonespeakApi.AccountApi* | [**accountUpdateCallRecording**](docs/AccountApi.md#accountUpdateCallRecording) | **PUT** /client/Account/{id}/CallRecording | Update Call Recording
*PhonespeakApi.AccountApi* | [**accountUpdateCompanyAddress**](docs/AccountApi.md#accountUpdateCompanyAddress) | **PUT** /client/Account/{id}/CompanyAddress | Update company address
*PhonespeakApi.AccountApi* | [**accountUpdateCreditCard**](docs/AccountApi.md#accountUpdateCreditCard) | **PUT** /client/Account/{id}/CreditCard | Update credit card
*PhonespeakApi.AccountApi* | [**accountUpdateE911Address**](docs/AccountApi.md#accountUpdateE911Address) | **PUT** /client/Account/{id}/E911Address | Update E911 address
*PhonespeakApi.AccountApi* | [**accountUpdateInvoice**](docs/AccountApi.md#accountUpdateInvoice) | **PUT** /client/Account/{id}/Invoice/{invoiceId} | Update invoice
*PhonespeakApi.AccountApi* | [**accountUpdateSelectedMusicOnHold**](docs/AccountApi.md#accountUpdateSelectedMusicOnHold) | **PUT** /client/Account/{id}/MusicOnHold/{mohId} | Set MusicOnHold
*PhonespeakApi.AccountApi* | [**accountUpdateSubscriptionTrial**](docs/AccountApi.md#accountUpdateSubscriptionTrial) | **PUT** /client/Account/{id}/Subscription/Trial | 
*PhonespeakApi.AccountApi* | [**accountUpdateTimezone**](docs/AccountApi.md#accountUpdateTimezone) | **PUT** /client/Account/{id}/Timezone | Update timezone
*PhonespeakApi.AccountApi* | [**accountUploadMusicOnHold**](docs/AccountApi.md#accountUploadMusicOnHold) | **POST** /client/Account/{id}/MusicOnHold | Upload MusicOnHold
*PhonespeakApi.AccountApi* | [**accountVerifyCreditCard**](docs/AccountApi.md#accountVerifyCreditCard) | **GET** /client/Account/CreditCard/Verify | Create credit card
*PhonespeakApi.AccountApi* | [**accountVerifyInternationalCall**](docs/AccountApi.md#accountVerifyInternationalCall) | **PUT** /client/Account/{id}/InternationalCall | Verify international call
*PhonespeakApi.AuthenticationApi* | [**getBearerAuthToken**](docs/AuthenticationApi.md#getBearerAuthToken) | **POST** /token | Authenticates provided credentials and returns an access token
*PhonespeakApi.BillingApi* | [**billingCheckout**](docs/BillingApi.md#billingCheckout) | **POST** /client/Billing/Checkout | 
*PhonespeakApi.BillingApi* | [**billingCreateInvoice**](docs/BillingApi.md#billingCreateInvoice) | **POST** /client/Billing/Invoice | 
*PhonespeakApi.BillingApi* | [**billingPaymentTracking**](docs/BillingApi.md#billingPaymentTracking) | **POST** /client/Billing/Payment/Tracking | 
*PhonespeakApi.BillingApi* | [**billingUpdateSubscription**](docs/BillingApi.md#billingUpdateSubscription) | **POST** /client/Billing/Subscription | 
*PhonespeakApi.CdrApi* | [**cdrCallLogExport**](docs/CdrApi.md#cdrCallLogExport) | **POST** /client/Cdr/{accountId}/CallLogExport | Call Log
*PhonespeakApi.CdrApi* | [**cdrCreate**](docs/CdrApi.md#cdrCreate) | **POST** /client/Cdr | Create a single cdr
*PhonespeakApi.CdrApi* | [**cdrCreateCallRecording**](docs/CdrApi.md#cdrCreateCallRecording) | **POST** /client/Cdr/{ownerId}CallRecording/{participant}/Participant | Create Call Recording
*PhonespeakApi.CdrApi* | [**cdrDelete**](docs/CdrApi.md#cdrDelete) | **DELETE** /client/Cdr/{id} | Delete a single cdr
*PhonespeakApi.CdrApi* | [**cdrDeleteCallLog**](docs/CdrApi.md#cdrDeleteCallLog) | **DELETE** /client/Cdr/{cdrId}/CallLog | Call Log
*PhonespeakApi.CdrApi* | [**cdrDeleteCallRecording**](docs/CdrApi.md#cdrDeleteCallRecording) | **DELETE** /client/Cdr/{id}/CallRecording | Delete Call Recording
*PhonespeakApi.CdrApi* | [**cdrDeleteCallSession**](docs/CdrApi.md#cdrDeleteCallSession) | **DELETE** /client/Cdr/{accountId}/CallSession | Delete Call Session
*PhonespeakApi.CdrApi* | [**cdrDeleteRecentCall**](docs/CdrApi.md#cdrDeleteRecentCall) | **DELETE** /client/Cdr/{id}/RecentCalls/{teammateId} | Delete recent call
*PhonespeakApi.CdrApi* | [**cdrGet**](docs/CdrApi.md#cdrGet) | **GET** /client/Cdr/{id} | Retrieve a single cdr
*PhonespeakApi.CdrApi* | [**cdrGetCallRecording**](docs/CdrApi.md#cdrGetCallRecording) | **GET** /client/Cdr/{ownerId}/CallRecording/{id} | Get Call Recording
*PhonespeakApi.CdrApi* | [**cdrList**](docs/CdrApi.md#cdrList) | **GET** /client/Cdr/{accountId}/List | List all cdrs by account, team mate or team
*PhonespeakApi.CdrApi* | [**cdrListCallLog**](docs/CdrApi.md#cdrListCallLog) | **POST** /client/Cdr/{accountId}/CallLog | Call Log
*PhonespeakApi.CdrApi* | [**cdrListCallRecording**](docs/CdrApi.md#cdrListCallRecording) | **GET** /client/Cdr/{ownerId}/CallRecording | List Call Recording
*PhonespeakApi.CdrApi* | [**cdrListCallSession**](docs/CdrApi.md#cdrListCallSession) | **GET** /client/Cdr/{accountId}/CallSession | List Call Session
*PhonespeakApi.CdrApi* | [**cdrListRecentActivity**](docs/CdrApi.md#cdrListRecentActivity) | **GET** /client/Cdr/{id}/RecentActivity/{participant} | Get all recent call
*PhonespeakApi.CdrApi* | [**cdrListRecentCalls**](docs/CdrApi.md#cdrListRecentCalls) | **GET** /client/Cdr/{id}/RecentCalls | Get all recent call
*PhonespeakApi.CdrApi* | [**cdrListRecentCalls_0**](docs/CdrApi.md#cdrListRecentCalls_0) | **POST** /client/Cdr/{id}/RecentCalls/dummyendpoint | Get all recent call
*PhonespeakApi.CdrApi* | [**cdrListTeamRecentCall**](docs/CdrApi.md#cdrListTeamRecentCall) | **GET** /client/Cdr/{id}/TeamRecentCalls | Get all team recent call
*PhonespeakApi.CdrApi* | [**cdrUnreadRecentCallCount**](docs/CdrApi.md#cdrUnreadRecentCallCount) | **GET** /client/Cdr/{id}/RecentCalls/UnreadCount | Total Unread Recent
*PhonespeakApi.CdrApi* | [**cdrUpdateCallRecording**](docs/CdrApi.md#cdrUpdateCallRecording) | **PUT** /client/Cdr/{id}/CallRecording | Update Call Recording
*PhonespeakApi.CdrApi* | [**cdrUpdateExtensionStatus**](docs/CdrApi.md#cdrUpdateExtensionStatus) | **POST** /client/Cdr/Extension | Portsip update extension status
*PhonespeakApi.CdrApi* | [**cdrUpdateRecentCallsRead**](docs/CdrApi.md#cdrUpdateRecentCallsRead) | **PUT** /client/Cdr/{id}/RecentCalls/Read | Update recent call read
*PhonespeakApi.CdrApi* | [**cdrUpdateTeamRecentCallReadStatus**](docs/CdrApi.md#cdrUpdateTeamRecentCallReadStatus) | **PUT** /client/Cdr/{id}/TeamRecentCalls/{ownerId}/Read | Get all team recent call
*PhonespeakApi.ChatApi* | [**chatArchiveConversation**](docs/ChatApi.md#chatArchiveConversation) | **PUT** /client/Chat/Archive/{id} | Archive conversation
*PhonespeakApi.ChatApi* | [**chatCreateConversation**](docs/ChatApi.md#chatCreateConversation) | **POST** /client/Chat/Conversation | Create conversation
*PhonespeakApi.ChatApi* | [**chatCreateMessage**](docs/ChatApi.md#chatCreateMessage) | **POST** /client/Chat/Message | Send Message
*PhonespeakApi.ChatApi* | [**chatDeleteConversation**](docs/ChatApi.md#chatDeleteConversation) | **DELETE** /client/Chat/Conversation/{conversationId} | Delete Conversation
*PhonespeakApi.ChatApi* | [**chatDeleteMessage**](docs/ChatApi.md#chatDeleteMessage) | **DELETE** /client/Chat/Message/{messageId} | Delete Message
*PhonespeakApi.ChatApi* | [**chatGetConversation**](docs/ChatApi.md#chatGetConversation) | **GET** /client/Chat/Conversation/{conversationId} | Get Conversation
*PhonespeakApi.ChatApi* | [**chatGetExistingConversation**](docs/ChatApi.md#chatGetExistingConversation) | **POST** /client/Chat/ExistingConversation | Get Existing Conversation
*PhonespeakApi.ChatApi* | [**chatGetUnreadConversationCount**](docs/ChatApi.md#chatGetUnreadConversationCount) | **GET** /client/Chat/UnreadConversationCount/{teammateId} | Get Unread Conversation Count
*PhonespeakApi.ChatApi* | [**chatListConversation**](docs/ChatApi.md#chatListConversation) | **GET** /client/Chat/Conversation | List the conversation
*PhonespeakApi.ChatApi* | [**chatPinConversation**](docs/ChatApi.md#chatPinConversation) | **PUT** /client/Chat/Pin/{id} | Pin conversation
*PhonespeakApi.ChatApi* | [**chatSendSMS**](docs/ChatApi.md#chatSendSMS) | **POST** /client/Chat/{id}/sms | Testing
*PhonespeakApi.ChatApi* | [**chatUnArchiveConversation**](docs/ChatApi.md#chatUnArchiveConversation) | **PUT** /client/Chat/UnArchive/{id} | UnArchive conversation
*PhonespeakApi.ChatApi* | [**chatUnpinConversation**](docs/ChatApi.md#chatUnpinConversation) | **PUT** /client/Chat/Unpin/{id} | Unpin conversation
*PhonespeakApi.ChatApi* | [**chatUpdateAllMessagesToRead**](docs/ChatApi.md#chatUpdateAllMessagesToRead) | **PUT** /client/Chat/UpdateAllMessagesToRead/{teammateId} | Update all conversation&#39;s messages to read
*PhonespeakApi.ChatApi* | [**chatUpdateGroupImage**](docs/ChatApi.md#chatUpdateGroupImage) | **PUT** /client/Chat/GroupImage/{conversationId} | Update Group Image
*PhonespeakApi.ChatApi* | [**chatUpdateGroupName**](docs/ChatApi.md#chatUpdateGroupName) | **PUT** /client/Chat/GroupName/{conversationId} | Update Group Name
*PhonespeakApi.CloudSoftPhoneApi* | [**cloudSoftPhoneFetchMessage**](docs/CloudSoftPhoneApi.md#cloudSoftPhoneFetchMessage) | **POST** /CloudSoftPhone/Message/Fetch | List all contacts
*PhonespeakApi.CloudSoftPhoneApi* | [**cloudSoftPhoneListContacts**](docs/CloudSoftPhoneApi.md#cloudSoftPhoneListContacts) | **GET** /CloudSoftPhone/Contact | List all contacts
*PhonespeakApi.CloudSoftPhoneApi* | [**cloudSoftPhoneLogin**](docs/CloudSoftPhoneApi.md#cloudSoftPhoneLogin) | **GET** /CloudSoftPhone/Prov | Login
*PhonespeakApi.CloudSoftPhoneApi* | [**cloudSoftPhonePushTokenReporter**](docs/CloudSoftPhoneApi.md#cloudSoftPhonePushTokenReporter) | **POST** /CloudSoftPhone/PushToken | List all contacts
*PhonespeakApi.CloudSoftPhoneApi* | [**cloudSoftPhoneSendMessage**](docs/CloudSoftPhoneApi.md#cloudSoftPhoneSendMessage) | **POST** /CloudSoftPhone/Message | List all contacts
*PhonespeakApi.CompanyNumberApi* | [**companyNumberAddPhoneNumber**](docs/CompanyNumberApi.md#companyNumberAddPhoneNumber) | **POST** /client/CompanyNumber/{id}/PhoneNumber | Add Phone Number for Company Number
*PhonespeakApi.CompanyNumberApi* | [**companyNumberCreate**](docs/CompanyNumberApi.md#companyNumberCreate) | **POST** /client/CompanyNumber | Create a single Company Number
*PhonespeakApi.CompanyNumberApi* | [**companyNumberCreateIvr**](docs/CompanyNumberApi.md#companyNumberCreateIvr) | **POST** /client/CompanyNumber/{id}/Ivr | Create Company Number&#39;s ivr
*PhonespeakApi.CompanyNumberApi* | [**companyNumberDelete**](docs/CompanyNumberApi.md#companyNumberDelete) | **DELETE** /client/CompanyNumber/{id} | Delete a single Company Number
*PhonespeakApi.CompanyNumberApi* | [**companyNumberDeleteIvr**](docs/CompanyNumberApi.md#companyNumberDeleteIvr) | **DELETE** /client/CompanyNumber/{id}/Ivr/{ivrNumber} | Delete Company Number&#39;s ivr
*PhonespeakApi.CompanyNumberApi* | [**companyNumberDeleteIvrGreeting**](docs/CompanyNumberApi.md#companyNumberDeleteIvrGreeting) | **DELETE** /client/CompanyNumber/{id}/Ivr/{ivrNumber}/Greeting/{greetingId} | Delete Ivr Greeting File
*PhonespeakApi.CompanyNumberApi* | [**companyNumberDeletePhoneNumber**](docs/CompanyNumberApi.md#companyNumberDeletePhoneNumber) | **DELETE** /client/CompanyNumber/{id}/PhoneNumber/{phoneNumberId} | Delete Phone Number for Company Number
*PhonespeakApi.CompanyNumberApi* | [**companyNumberGet**](docs/CompanyNumberApi.md#companyNumberGet) | **GET** /client/CompanyNumber/{id} | Retrieve a single Company Number by id
*PhonespeakApi.CompanyNumberApi* | [**companyNumberIvrConvertTextToSpeech**](docs/CompanyNumberApi.md#companyNumberIvrConvertTextToSpeech) | **POST** /client/CompanyNumber/{id}/Ivr/{ivrNumber}/Greeting/SpeechGreeting | Ivr Convert text to speech
*PhonespeakApi.CompanyNumberApi* | [**companyNumberList**](docs/CompanyNumberApi.md#companyNumberList) | **GET** /client/CompanyNumber | List all Company Numbers by account
*PhonespeakApi.CompanyNumberApi* | [**companyNumberListAvailableTeammates**](docs/CompanyNumberApi.md#companyNumberListAvailableTeammates) | **GET** /client/CompanyNumber/{id}/ListAvailableTeammates | Get Teammate list for company number
*PhonespeakApi.CompanyNumberApi* | [**companyNumberListIvrGreetings**](docs/CompanyNumberApi.md#companyNumberListIvrGreetings) | **GET** /client/CompanyNumber/{id}/Ivr/{ivrNumber}/Greeting | List Ivr Greetings for a team
*PhonespeakApi.CompanyNumberApi* | [**companyNumberUpdate**](docs/CompanyNumberApi.md#companyNumberUpdate) | **PUT** /client/CompanyNumber/{id} | Update a single Company Number by id
*PhonespeakApi.CompanyNumberApi* | [**companyNumberUpdateBusinessHour**](docs/CompanyNumberApi.md#companyNumberUpdateBusinessHour) | **PUT** /client/CompanyNumber/{id}/BusinessHour | Update Company Number Business Hour by id
*PhonespeakApi.CompanyNumberApi* | [**companyNumberUpdateCallerIdPermission**](docs/CompanyNumberApi.md#companyNumberUpdateCallerIdPermission) | **PUT** /client/CompanyNumber/{id}/CallerIdPermission | Add teammate for Company Number
*PhonespeakApi.CompanyNumberApi* | [**companyNumberUpdateClosedHourHandling**](docs/CompanyNumberApi.md#companyNumberUpdateClosedHourHandling) | **PUT** /client/CompanyNumber/{id}/ClosedHourHandling | Update Company Number Closed Hour Handling
*PhonespeakApi.CompanyNumberApi* | [**companyNumberUpdateIvrKey**](docs/CompanyNumberApi.md#companyNumberUpdateIvrKey) | **PUT** /client/CompanyNumber/{id}/Ivr/{ivrNumber}/IvrKey/{keyNumber} | Update Ivr Key
*PhonespeakApi.CompanyNumberApi* | [**companyNumberUpdateIvrName**](docs/CompanyNumberApi.md#companyNumberUpdateIvrName) | **PUT** /client/CompanyNumber/{id}/Ivr/{ivrNumber}/Name/{ivrName} | Update Company Number&#39;s ivr
*PhonespeakApi.CompanyNumberApi* | [**companyNumberUpdateIvrTimeout**](docs/CompanyNumberApi.md#companyNumberUpdateIvrTimeout) | **PUT** /client/CompanyNumber/{id}/Ivr/{ivrNumber} | Update Ivr Timeout
*PhonespeakApi.CompanyNumberApi* | [**companyNumberUpdateOpenHourHandling**](docs/CompanyNumberApi.md#companyNumberUpdateOpenHourHandling) | **PUT** /client/CompanyNumber/{id}/OpenHourHandling | Update Company Number Open Hour Handling
*PhonespeakApi.CompanyNumberApi* | [**companyNumberUpdatePhoneNumber**](docs/CompanyNumberApi.md#companyNumberUpdatePhoneNumber) | **PUT** /client/CompanyNumber/{id}/PhoneNumber/{phoneNumberId} | Add Phone Number
*PhonespeakApi.CompanyNumberApi* | [**companyNumberUpdateSMSHandling**](docs/CompanyNumberApi.md#companyNumberUpdateSMSHandling) | **PUT** /client/CompanyNumber/{id}/Sms/SMSHandling | Update SMS Handling for Company Number
*PhonespeakApi.CompanyNumberApi* | [**companyNumberUpdateSelectedIvrGreeting**](docs/CompanyNumberApi.md#companyNumberUpdateSelectedIvrGreeting) | **PUT** /client/CompanyNumber/{id}/Ivr/{ivrNumber}/Greeting/{greetingId} | Update/Set a Company Number&#39;s default Voicemail Greeting
*PhonespeakApi.CompanyNumberApi* | [**companyNumberUploadIvrGreeting**](docs/CompanyNumberApi.md#companyNumberUploadIvrGreeting) | **POST** /client/CompanyNumber/{id}/Ivr/{ivrNumber}/Greeting | Upload Ivr Greeting File
*PhonespeakApi.ContactApi* | [**contactBlock**](docs/ContactApi.md#contactBlock) | **PUT** /client/Contact/{id}/Block | Block contact (either contactId or callerNumber)
*PhonespeakApi.ContactApi* | [**contactBlockedList**](docs/ContactApi.md#contactBlockedList) | **GET** /client/Contact/{id}/BlockedList | List all blocked contacts and number
*PhonespeakApi.ContactApi* | [**contactCreate**](docs/ContactApi.md#contactCreate) | **POST** /client/Contact/{id}/Create | Create a single contact
*PhonespeakApi.ContactApi* | [**contactDelete**](docs/ContactApi.md#contactDelete) | **DELETE** /client/Contact/{id}/Delete/{contactId} | Delete a single contact
*PhonespeakApi.ContactApi* | [**contactExportContact**](docs/ContactApi.md#contactExportContact) | **GET** /client/Contact/{teammateId}/Export | Import Contact
*PhonespeakApi.ContactApi* | [**contactFavourite**](docs/ContactApi.md#contactFavourite) | **PUT** /client/Contact/{id}/Favourite/{contactId} | SetFavourite contact
*PhonespeakApi.ContactApi* | [**contactGet**](docs/ContactApi.md#contactGet) | **GET** /client/Contact/{id}/Get/{contactId} | Retrieve a single contact
*PhonespeakApi.ContactApi* | [**contactGetFolder**](docs/ContactApi.md#contactGetFolder) | **GET** /client/Contact/{id}/Folder/{folderId} | Retrieve folder by id
*PhonespeakApi.ContactApi* | [**contactGetFolderList**](docs/ContactApi.md#contactGetFolderList) | **GET** /client/Contact/{id}/Folder | List all folder
*PhonespeakApi.ContactApi* | [**contactImportContact**](docs/ContactApi.md#contactImportContact) | **POST** /client/Contact/{teammateId}/Import | Import Contact
*PhonespeakApi.ContactApi* | [**contactList**](docs/ContactApi.md#contactList) | **GET** /client/Contact/{id}/List | List all contacts by team mate
*PhonespeakApi.ContactApi* | [**contactSharedList**](docs/ContactApi.md#contactSharedList) | **GET** /client/Contact/{id}/SharedList | List all shared contacts by team mate
*PhonespeakApi.ContactApi* | [**contactUnBlock**](docs/ContactApi.md#contactUnBlock) | **PUT** /client/Contact/{id}/UnBlock | UnBlock contact (either contactId or callerNumber)
*PhonespeakApi.ContactApi* | [**contactUnFavourite**](docs/ContactApi.md#contactUnFavourite) | **PUT** /client/Contact/{id}/UnFavourite/{contactId} | UnFavourite contact
*PhonespeakApi.ContactApi* | [**contactUpdate**](docs/ContactApi.md#contactUpdate) | **PUT** /client/Contact/{id}/Update | Update a single contact
*PhonespeakApi.CsrApi* | [**csrAddNumber**](docs/CsrApi.md#csrAddNumber) | **PUT** /client/Csr/Number/{id} | Add Phone Number
*PhonespeakApi.CsrApi* | [**csrApplyInvoiceCoupon**](docs/CsrApi.md#csrApplyInvoiceCoupon) | **POST** /client/Csr/Account/{id}/InvoiceCoupon | Apply Invoice Coupon
*PhonespeakApi.CsrApi* | [**csrApplySubscriptionCoupon**](docs/CsrApi.md#csrApplySubscriptionCoupon) | **POST** /client/Csr/Account/{id}/SubscriptionCoupon | Apply Subscription Coupon
*PhonespeakApi.CsrApi* | [**csrCallLogExport**](docs/CsrApi.md#csrCallLogExport) | **GET** /client/Csr/CallLog/Export | Export Call Log
*PhonespeakApi.CsrApi* | [**csrCheckLnp**](docs/CsrApi.md#csrCheckLnp) | **POST** /client/Csr/Account/Portin/CheckLnp | Check Lnp
*PhonespeakApi.CsrApi* | [**csrCompleteOrder**](docs/CsrApi.md#csrCompleteOrder) | **PUT** /client/Csr/Order/{orderId}/Complete | Complete Order
*PhonespeakApi.CsrApi* | [**csrCreate**](docs/CsrApi.md#csrCreate) | **POST** /client/Csr/Representative | Create a single Csr user
*PhonespeakApi.CsrApi* | [**csrCreateAccount**](docs/CsrApi.md#csrCreateAccount) | **POST** /client/Csr/Account | Create a single account
*PhonespeakApi.CsrApi* | [**csrCreateLnp**](docs/CsrApi.md#csrCreateLnp) | **POST** /client/Csr/Account/{accountId}/Portin | Create Lnp
*PhonespeakApi.CsrApi* | [**csrCreateProduct**](docs/CsrApi.md#csrCreateProduct) | **POST** /client/Csr/Product | Create Product
*PhonespeakApi.CsrApi* | [**csrDelete**](docs/CsrApi.md#csrDelete) | **DELETE** /client/Csr/Representative/{id} | Delete a single Csr user
*PhonespeakApi.CsrApi* | [**csrDeleteLnp**](docs/CsrApi.md#csrDeleteLnp) | **DELETE** /client/Csr/Account/{accountId}/Portin/{orderId} | Delete Lnp
*PhonespeakApi.CsrApi* | [**csrDeleteTeammate**](docs/CsrApi.md#csrDeleteTeammate) | **DELETE** /client/Csr/Account/{id}/Teammate/{teammateId} | Delete a single teammate
*PhonespeakApi.CsrApi* | [**csrForgotPassword**](docs/CsrApi.md#csrForgotPassword) | **POST** /client/Csr/ForgotPassword | Csr Forgot password
*PhonespeakApi.CsrApi* | [**csrGet**](docs/CsrApi.md#csrGet) | **GET** /client/Csr/Representative/{id} | Retrieve a single Csr user
*PhonespeakApi.CsrApi* | [**csrGetAccount**](docs/CsrApi.md#csrGetAccount) | **GET** /client/Csr/Account/{id} | Retrieve a single account
*PhonespeakApi.CsrApi* | [**csrGetCallLog**](docs/CsrApi.md#csrGetCallLog) | **GET** /client/Csr/CallLog/{id} | List all call log
*PhonespeakApi.CsrApi* | [**csrGetLnp**](docs/CsrApi.md#csrGetLnp) | **GET** /client/Csr/Account/{accountId}/Portin/{orderId} | Get Lnp
*PhonespeakApi.CsrApi* | [**csrGetOrder**](docs/CsrApi.md#csrGetOrder) | **GET** /client/Csr/Order/{orderId} | Get Order
*PhonespeakApi.CsrApi* | [**csrGetUncoveredRate**](docs/CsrApi.md#csrGetUncoveredRate) | **GET** /client/Csr/RateDeck/UncoveredRate | Get current Uncovered Rate
*PhonespeakApi.CsrApi* | [**csrGiveCredit**](docs/CsrApi.md#csrGiveCredit) | **POST** /client/Csr/Account/{id}/Credit | Give Credit
*PhonespeakApi.CsrApi* | [**csrImportRateDeck**](docs/CsrApi.md#csrImportRateDeck) | **POST** /client/Csr/RateDeck/Import | Import Rate Deck
*PhonespeakApi.CsrApi* | [**csrList**](docs/CsrApi.md#csrList) | **GET** /client/Csr/Representative | Retrieve list of Csr users
*PhonespeakApi.CsrApi* | [**csrListAccountCompanyNumber**](docs/CsrApi.md#csrListAccountCompanyNumber) | **GET** /client/Csr/Account/{id}/CompanyNumber | List all Company Numbers by account
*PhonespeakApi.CsrApi* | [**csrListAccountPhoneNumber**](docs/CsrApi.md#csrListAccountPhoneNumber) | **GET** /client/Csr/Account/{id}/PhoneNumber | List Phone Number
*PhonespeakApi.CsrApi* | [**csrListAccountTeammate**](docs/CsrApi.md#csrListAccountTeammate) | **GET** /client/Csr/Account/{id}/Teammate | Get all teammates by account
*PhonespeakApi.CsrApi* | [**csrListAccounts**](docs/CsrApi.md#csrListAccounts) | **GET** /client/Csr/Account | Retrieve list of all accounts
*PhonespeakApi.CsrApi* | [**csrListCallLog**](docs/CsrApi.md#csrListCallLog) | **GET** /client/Csr/CallLog | List all call log
*PhonespeakApi.CsrApi* | [**csrListCharge**](docs/CsrApi.md#csrListCharge) | **GET** /client/Csr/Account/{id}/Charge | List Charge
*PhonespeakApi.CsrApi* | [**csrListLnp**](docs/CsrApi.md#csrListLnp) | **POST** /client/Csr/Account/Portin/ListLnp | List Lnp
*PhonespeakApi.CsrApi* | [**csrListOrder**](docs/CsrApi.md#csrListOrder) | **GET** /client/Csr/Order/List | List Order
*PhonespeakApi.CsrApi* | [**csrListPhysicalPhoneByOrderId**](docs/CsrApi.md#csrListPhysicalPhoneByOrderId) | **GET** /client/Csr/Account/{id}/PhysicalPhone/{orderId} | List Physical Phone by orderId
*PhonespeakApi.CsrApi* | [**csrLogin**](docs/CsrApi.md#csrLogin) | **POST** /client/Csr/Login | Login
*PhonespeakApi.CsrApi* | [**csrManualCharge**](docs/CsrApi.md#csrManualCharge) | **POST** /client/Csr/Account/{id}/Charge | Manual Charge
*PhonespeakApi.CsrApi* | [**csrMoveNumber**](docs/CsrApi.md#csrMoveNumber) | **PUT** /client/Csr/Number/{id}/Move | Move Number
*PhonespeakApi.CsrApi* | [**csrRefund**](docs/CsrApi.md#csrRefund) | **GET** /client/Csr/Account/{accountId}/Refund/{chargeId} | Create Refund
*PhonespeakApi.CsrApi* | [**csrUpdate**](docs/CsrApi.md#csrUpdate) | **PUT** /client/Csr/Representative/{id} | Update a single Csr user
*PhonespeakApi.CsrApi* | [**csrUpdateAccountDetails**](docs/CsrApi.md#csrUpdateAccountDetails) | **PUT** /client/Csr/Account/{id} | Update account
*PhonespeakApi.CsrApi* | [**csrUpdateAccountPackage**](docs/CsrApi.md#csrUpdateAccountPackage) | **PUT** /client/Csr/Account/{id}/Package | Update account package
*PhonespeakApi.CsrApi* | [**csrUpdateAccountSetting**](docs/CsrApi.md#csrUpdateAccountSetting) | **PUT** /client/Csr/Account/{id}/Setting | Update Setting
*PhonespeakApi.CsrApi* | [**csrUpdateAccountStatus**](docs/CsrApi.md#csrUpdateAccountStatus) | **PUT** /client/Csr/Account/{id}/Status | Update Account Status
*PhonespeakApi.CsrApi* | [**csrUpdateCsrPassword**](docs/CsrApi.md#csrUpdateCsrPassword) | **PUT** /client/Csr/Representative/{id}/Password | Update a single Csr User Password
*PhonespeakApi.CsrApi* | [**csrUpdateMacAddress**](docs/CsrApi.md#csrUpdateMacAddress) | **PUT** /client/Csr/Account/{id}/PhysicalPhone | Update Physical Phone Mac Address
*PhonespeakApi.CsrApi* | [**csrUpdateReferenceId**](docs/CsrApi.md#csrUpdateReferenceId) | **PUT** /client/Csr/Order/{orderId}/Reference/{referenceId} | Update Reference Id
*PhonespeakApi.CsrApi* | [**csrUpdateShippingAddress**](docs/CsrApi.md#csrUpdateShippingAddress) | **PUT** /client/Csr/Order/{orderId}/Address | Update Shipping Address
*PhonespeakApi.CsrApi* | [**csrUpdateTollFreeRateDeck**](docs/CsrApi.md#csrUpdateTollFreeRateDeck) | **PUT** /client/Csr/RateDeck/TollFree | Update TollFree RateDeck
*PhonespeakApi.CsrApi* | [**csrUpdateTrackingLink**](docs/CsrApi.md#csrUpdateTrackingLink) | **POST** /client/Csr/Order/{orderId}/Tracking | Update Tracking Link
*PhonespeakApi.CsrApi* | [**csrUpdateUncoveredRateDeck**](docs/CsrApi.md#csrUpdateUncoveredRateDeck) | **PUT** /client/Csr/RateDeck/UncoveredRate | Update Uncovered RateDeck
*PhonespeakApi.CsrApi* | [**csrUploadLoas**](docs/CsrApi.md#csrUploadLoas) | **PUT** /client/Csr/Account/{id}/Portin/{orderId}/UploadLoas | Upoad Loas
*PhonespeakApi.CsrApi* | [**csrUploadProfileImage**](docs/CsrApi.md#csrUploadProfileImage) | **POST** /client/Csr/Representative/{id}/ProfileImage | Upload profile image (format-accepted: .gif |.jpg |.jpeg |.png)
*PhonespeakApi.DeskPhoneApi* | [**deskPhoneAddToCart**](docs/DeskPhoneApi.md#deskPhoneAddToCart) | **POST** /client/deskphone/Cart | Add to Cart
*PhonespeakApi.DeskPhoneApi* | [**deskPhoneConfirmOrder**](docs/DeskPhoneApi.md#deskPhoneConfirmOrder) | **PUT** /client/deskphone/Order/Confirm/{orderId} | Confirm Order
*PhonespeakApi.DeskPhoneApi* | [**deskPhoneDeleteAllCartByOwnerId**](docs/DeskPhoneApi.md#deskPhoneDeleteAllCartByOwnerId) | **DELETE** /client/deskphone/Cart/Owner/{ownerId} | Delete All Cart By Owner Id
*PhonespeakApi.DeskPhoneApi* | [**deskPhoneDeleteCart**](docs/DeskPhoneApi.md#deskPhoneDeleteCart) | **DELETE** /client/deskphone/Cart/{cartId} | Delete Single cart
*PhonespeakApi.DeskPhoneApi* | [**deskPhoneGetCart**](docs/DeskPhoneApi.md#deskPhoneGetCart) | **GET** /client/deskphone/Cart/{cartId} | Get Single cart
*PhonespeakApi.DeskPhoneApi* | [**deskPhoneGetOrder**](docs/DeskPhoneApi.md#deskPhoneGetOrder) | **GET** /client/deskphone/Order/{orderId} | Get Order
*PhonespeakApi.DeskPhoneApi* | [**deskPhoneGetProduct**](docs/DeskPhoneApi.md#deskPhoneGetProduct) | **GET** /client/deskphone/Product/{productId} | Get Product
*PhonespeakApi.DeskPhoneApi* | [**deskPhoneListCart**](docs/DeskPhoneApi.md#deskPhoneListCart) | **GET** /client/deskphone/Cart/{ownerId}/List | Get List of Cart by owner id
*PhonespeakApi.DeskPhoneApi* | [**deskPhoneListDeskPhone**](docs/DeskPhoneApi.md#deskPhoneListDeskPhone) | **GET** /client/deskphone/DeskPhone/List | List DeskPhone
*PhonespeakApi.DeskPhoneApi* | [**deskPhoneListOrder**](docs/DeskPhoneApi.md#deskPhoneListOrder) | **GET** /client/deskphone/Order/{ownerId}/List | List Order by OwnerId
*PhonespeakApi.DeskPhoneApi* | [**deskPhoneListProduct**](docs/DeskPhoneApi.md#deskPhoneListProduct) | **GET** /client/deskphone/Product | Get List of Product
*PhonespeakApi.DeskPhoneApi* | [**deskPhoneListShippingOption**](docs/DeskPhoneApi.md#deskPhoneListShippingOption) | **GET** /client/deskphone/ShippingOption/List | List Shipping Option
*PhonespeakApi.DeskPhoneApi* | [**deskPhonePlaceOrder**](docs/DeskPhoneApi.md#deskPhonePlaceOrder) | **POST** /client/deskphone/Order/Place | Place Order
*PhonespeakApi.DeskPhoneApi* | [**deskPhoneUpdateCart**](docs/DeskPhoneApi.md#deskPhoneUpdateCart) | **PUT** /client/deskphone/Cart/{cartId} | Update Single cart
*PhonespeakApi.DeskPhoneApi* | [**deskPhoneUpdateCarts**](docs/DeskPhoneApi.md#deskPhoneUpdateCarts) | **PUT** /client/deskphone/Cart | Update List of Cart
*PhonespeakApi.EmailApi* | [**emailCreate**](docs/EmailApi.md#emailCreate) | **POST** /client/Email/Create | Create a single email template
*PhonespeakApi.EmailApi* | [**emailDelete**](docs/EmailApi.md#emailDelete) | **DELETE** /client/Email/{templateid}/Delete | Delete email template
*PhonespeakApi.EmailApi* | [**emailGet**](docs/EmailApi.md#emailGet) | **GET** /client/Email/{templateid}/Get | Retrieve a single email template by id
*PhonespeakApi.EmailApi* | [**emailList**](docs/EmailApi.md#emailList) | **GET** /client/Email/List | Retrieve list of email templates
*PhonespeakApi.EmailApi* | [**emailUpdate**](docs/EmailApi.md#emailUpdate) | **PUT** /client/Email/{id}/Update | Update a single email template
*PhonespeakApi.NoteApi* | [**noteCreate**](docs/NoteApi.md#noteCreate) | **POST** /client/note/Create | Create a single note
*PhonespeakApi.NoteApi* | [**noteDelete**](docs/NoteApi.md#noteDelete) | **DELETE** /client/note/{noteId} | Delete note
*PhonespeakApi.NoteApi* | [**noteGet**](docs/NoteApi.md#noteGet) | **GET** /client/note/{noteId} | Retrieve a single Note
*PhonespeakApi.NoteApi* | [**noteList**](docs/NoteApi.md#noteList) | **GET** /client/note/{ownerId}/List | List Notes
*PhonespeakApi.NoteApi* | [**noteUpdate**](docs/NoteApi.md#noteUpdate) | **PUT** /client/note/{noteId} | Update note
*PhonespeakApi.NumberApi* | [**numberGet**](docs/NumberApi.md#numberGet) | **POST** /client/Number/Get | Get List of Numbers
*PhonespeakApi.NumberApi* | [**numberGetAreaCode**](docs/NumberApi.md#numberGetAreaCode) | **GET** /client/Number/GetAreaCodes | Get Area Codes
*PhonespeakApi.NumberApi* | [**numberGetPhoneNumDetails**](docs/NumberApi.md#numberGetPhoneNumDetails) | **GET** /client/Number/GetPhoneNumDetails | Get Phone Number Detail
*PhonespeakApi.NumberApi* | [**numberGetStates**](docs/NumberApi.md#numberGetStates) | **GET** /client/Number/GetStates | Get available states
*PhonespeakApi.NumberApi* | [**numberGetUserState**](docs/NumberApi.md#numberGetUserState) | **GET** /client/Number/UserState | 
*PhonespeakApi.NumberApi* | [**numberMoveNumber**](docs/NumberApi.md#numberMoveNumber) | **PUT** /client/Number/{id}/Move | Move Number
*PhonespeakApi.NumberApi* | [**numberReserve**](docs/NumberApi.md#numberReserve) | **POST** /client/Number/Reserve | Reserve Number
*PhonespeakApi.NumberApi* | [**numberValidateE911Address**](docs/NumberApi.md#numberValidateE911Address) | **POST** /client/Number/E911Address | Validate the E911 address
*PhonespeakApi.ServiceApi* | [**serviceInsertGLog**](docs/ServiceApi.md#serviceInsertGLog) | **POST** /client/Service/GLog | Insert GLog
*PhonespeakApi.SmsApi* | [**smsCreateBandwidthSmsInbound**](docs/SmsApi.md#smsCreateBandwidthSmsInbound) | **POST** /client/Sms/Bandwidth | Receive SMS from Bandwidth
*PhonespeakApi.SmsApi* | [**smsCreateBandwidthSmsInboundV2**](docs/SmsApi.md#smsCreateBandwidthSmsInboundV2) | **POST** /client/Sms/Bandwidth/v2 | Receive SMS from Bandwidth
*PhonespeakApi.SmsApi* | [**smsCreateIntelliquentSmsInbound**](docs/SmsApi.md#smsCreateIntelliquentSmsInbound) | **POST** /client/Sms/Inteliquent | Receive SMS from Inteliquent
*PhonespeakApi.SubscriptionApi* | [**subscriptionCreatePackage**](docs/SubscriptionApi.md#subscriptionCreatePackage) | **POST** /client/subscription/Package | Create Package
*PhonespeakApi.SubscriptionApi* | [**subscriptionCreateUrl**](docs/SubscriptionApi.md#subscriptionCreateUrl) | **POST** /client/subscription/Url/Create | Create Url
*PhonespeakApi.SubscriptionApi* | [**subscriptionDelete**](docs/SubscriptionApi.md#subscriptionDelete) | **DELETE** /client/subscription/Package/{id} | Delete a single package
*PhonespeakApi.SubscriptionApi* | [**subscriptionDeleteUrl**](docs/SubscriptionApi.md#subscriptionDeleteUrl) | **DELETE** /client/subscription/Url/{urlId} | Delete Url
*PhonespeakApi.SubscriptionApi* | [**subscriptionGetUrl**](docs/SubscriptionApi.md#subscriptionGetUrl) | **GET** /client/subscription/Url/{urlId} | Get Single Url
*PhonespeakApi.SubscriptionApi* | [**subscriptionListInvoiceCoupon**](docs/SubscriptionApi.md#subscriptionListInvoiceCoupon) | **GET** /client/subscription/Coupon/Invoice | List Invoice Coupon
*PhonespeakApi.SubscriptionApi* | [**subscriptionListPackage**](docs/SubscriptionApi.md#subscriptionListPackage) | **GET** /client/subscription/Package | List all Package
*PhonespeakApi.SubscriptionApi* | [**subscriptionListPackagePlan**](docs/SubscriptionApi.md#subscriptionListPackagePlan) | **GET** /client/subscription/Package/Plan | List all plan
*PhonespeakApi.SubscriptionApi* | [**subscriptionListPlan**](docs/SubscriptionApi.md#subscriptionListPlan) | **GET** /client/subscription/Plan/{packageId} | List Plan
*PhonespeakApi.SubscriptionApi* | [**subscriptionListStripeProduct**](docs/SubscriptionApi.md#subscriptionListStripeProduct) | **GET** /client/subscription/StripeProduct/List | Get List of Stripe Product
*PhonespeakApi.SubscriptionApi* | [**subscriptionListSubscriptionCoupon**](docs/SubscriptionApi.md#subscriptionListSubscriptionCoupon) | **GET** /client/subscription/Coupon/Subscription | List Subscription Coupon
*PhonespeakApi.SubscriptionApi* | [**subscriptionListUrl**](docs/SubscriptionApi.md#subscriptionListUrl) | **GET** /client/subscription/Url/List | Get list of url
*PhonespeakApi.SubscriptionApi* | [**subscriptionUpdatePackage**](docs/SubscriptionApi.md#subscriptionUpdatePackage) | **PUT** /client/subscription/Package/{id} | Update Package
*PhonespeakApi.SubscriptionApi* | [**subscriptionUpdateUrl**](docs/SubscriptionApi.md#subscriptionUpdateUrl) | **PUT** /client/subscription/Url/{urlId} | Update Url
*PhonespeakApi.SupportApi* | [**supportGetLocation**](docs/SupportApi.md#supportGetLocation) | **GET** /client/Support/Location | 
*PhonespeakApi.SupportApi* | [**supportSupportSendEmail**](docs/SupportApi.md#supportSupportSendEmail) | **POST** /client/Support/Email | 
*PhonespeakApi.TeamApi* | [**teamConvertTextToSpeech**](docs/TeamApi.md#teamConvertTextToSpeech) | **POST** /client/Team/{id}/VoicemailGreeting/SpeechGreeting | Convert text to speech
*PhonespeakApi.TeamApi* | [**teamCreate**](docs/TeamApi.md#teamCreate) | **POST** /client/Team | Create a single team
*PhonespeakApi.TeamApi* | [**teamCreateIvr**](docs/TeamApi.md#teamCreateIvr) | **POST** /client/Team/{id}/Ivr | Create team&#39;s ivr
*PhonespeakApi.TeamApi* | [**teamDelete**](docs/TeamApi.md#teamDelete) | **DELETE** /client/Team/{id} | Delete a single team
*PhonespeakApi.TeamApi* | [**teamDeleteIvr**](docs/TeamApi.md#teamDeleteIvr) | **DELETE** /client/Team/{id}/Ivr/{ivrNumber} | Delete team&#39;s ivr
*PhonespeakApi.TeamApi* | [**teamDeleteIvrGreeting**](docs/TeamApi.md#teamDeleteIvrGreeting) | **DELETE** /client/Team/{id}/Ivr/{ivrNumber}/Greeting/{greetingId} | Delete Ivr Greeting File
*PhonespeakApi.TeamApi* | [**teamDeleteMusicOnHold**](docs/TeamApi.md#teamDeleteMusicOnHold) | **DELETE** /client/Team/{id}/MusicOnHold/{mohId} | Delete MusicOnHold file
*PhonespeakApi.TeamApi* | [**teamDeleteVoicemailGreeting**](docs/TeamApi.md#teamDeleteVoicemailGreeting) | **DELETE** /client/Team/{id}/VoicemailGreeting/{voicemailId} | Delete Voicemail Greeting File
*PhonespeakApi.TeamApi* | [**teamGet**](docs/TeamApi.md#teamGet) | **GET** /client/Team/{id} | Retrieve a single team by id
*PhonespeakApi.TeamApi* | [**teamIvrConvertTextToSpeech**](docs/TeamApi.md#teamIvrConvertTextToSpeech) | **POST** /client/Team/{id}/Ivr/{ivrNumber}/Greeting/SpeechGreeting | Ivr Convert text to speech
*PhonespeakApi.TeamApi* | [**teamList**](docs/TeamApi.md#teamList) | **GET** /client/Team | List all teams by account
*PhonespeakApi.TeamApi* | [**teamListAvailableNumber**](docs/TeamApi.md#teamListAvailableNumber) | **GET** /client/Team/{id}/AvailableNumber | List Caller Id
*PhonespeakApi.TeamApi* | [**teamListAvailableTeammates**](docs/TeamApi.md#teamListAvailableTeammates) | **GET** /client/Team/{id}/ListAvailableTeammates | Get Teammate list for team
*PhonespeakApi.TeamApi* | [**teamListIvrGreetings**](docs/TeamApi.md#teamListIvrGreetings) | **GET** /client/Team/{id}/Ivr/{ivrNumber}/Greeting | List Ivr Greetings for a team
*PhonespeakApi.TeamApi* | [**teamListMusicOnHold**](docs/TeamApi.md#teamListMusicOnHold) | **GET** /client/Team/{id}/MusicOnHold | List MusicOnHolds for team
*PhonespeakApi.TeamApi* | [**teamListTeamsByTeammate**](docs/TeamApi.md#teamListTeamsByTeammate) | **GET** /client/Team/Teammate | List all teams by teammate
*PhonespeakApi.TeamApi* | [**teamListVoicemailGreetings**](docs/TeamApi.md#teamListVoicemailGreetings) | **GET** /client/Team/{id}/VoicemailGreeting | List Voicemail Greetings for a team
*PhonespeakApi.TeamApi* | [**teamTeamSummary**](docs/TeamApi.md#teamTeamSummary) | **GET** /client/Team/{teamId}/TeamSummary | Team Summary
*PhonespeakApi.TeamApi* | [**teamUpdate**](docs/TeamApi.md#teamUpdate) | **PUT** /client/Team/{id} | Update a single team
*PhonespeakApi.TeamApi* | [**teamUpdateBusinessHour**](docs/TeamApi.md#teamUpdateBusinessHour) | **PUT** /client/Team/{id}/BusinessHour | Update team business hour
*PhonespeakApi.TeamApi* | [**teamUpdateCallQueue**](docs/TeamApi.md#teamUpdateCallQueue) | **PUT** /client/Team/{id}/CallQueue | Update team&#39;s call queue
*PhonespeakApi.TeamApi* | [**teamUpdateCallRouting**](docs/TeamApi.md#teamUpdateCallRouting) | **PUT** /client/Team/{id}/CallRouting | Update team call routing
*PhonespeakApi.TeamApi* | [**teamUpdateClosedHourHandling**](docs/TeamApi.md#teamUpdateClosedHourHandling) | **PUT** /client/Team/{id}/ClosedHourHandling | Update team close hour call handling
*PhonespeakApi.TeamApi* | [**teamUpdateIvrKey**](docs/TeamApi.md#teamUpdateIvrKey) | **PUT** /client/Team/{id}/Ivr/{ivrNumber}/IvrKey/{keyNumber} | Update Ivr Key
*PhonespeakApi.TeamApi* | [**teamUpdateIvrName**](docs/TeamApi.md#teamUpdateIvrName) | **PUT** /client/Team/{id}/Ivr/{ivrNumber}/Name/{ivrName} | Update team&#39;s ivr
*PhonespeakApi.TeamApi* | [**teamUpdateIvrTimeout**](docs/TeamApi.md#teamUpdateIvrTimeout) | **PUT** /client/Team/{id}/Ivr/{ivrNumber} | Update Ivr Timeout
*PhonespeakApi.TeamApi* | [**teamUpdateMissedCallHandling**](docs/TeamApi.md#teamUpdateMissedCallHandling) | **PUT** /client/Team/{id}/MissedCallHandling | Update team miss call handling
*PhonespeakApi.TeamApi* | [**teamUpdateOpenHourHandling**](docs/TeamApi.md#teamUpdateOpenHourHandling) | **PUT** /client/Team/{id}/OpenHourHandling | Update team open hour call handling
*PhonespeakApi.TeamApi* | [**teamUpdateRingGroup**](docs/TeamApi.md#teamUpdateRingGroup) | **PUT** /client/Team/{id}/RingGroup | Update team&#39;s ring group
*PhonespeakApi.TeamApi* | [**teamUpdateSelectedIvrGreeting**](docs/TeamApi.md#teamUpdateSelectedIvrGreeting) | **PUT** /client/Team/{id}/Ivr/{ivrNumber}/Greeting/{greetingId} | Update/Set a Team&#39;s default Voicemail Greeting
*PhonespeakApi.TeamApi* | [**teamUpdateSelectedMusicOnHold**](docs/TeamApi.md#teamUpdateSelectedMusicOnHold) | **PUT** /client/Team/{id}/MusicOnHold/{mohId} | Update/Set team&#39;s default MusicOnHold
*PhonespeakApi.TeamApi* | [**teamUpdateSelectedVoicemailGreeting**](docs/TeamApi.md#teamUpdateSelectedVoicemailGreeting) | **PUT** /client/Team/{id}/VoicemailGreeting/{voicemailId} | Update/Set a Team&#39;s default Voicemail Greeting
*PhonespeakApi.TeamApi* | [**teamUpdateTeammate**](docs/TeamApi.md#teamUpdateTeammate) | **PUT** /client/Team/{id}/Teammate | Update team&#39;s teammate list
*PhonespeakApi.TeamApi* | [**teamUploadIvrGreeting**](docs/TeamApi.md#teamUploadIvrGreeting) | **POST** /client/Team/{id}/Ivr/{ivrNumber}/Greeting | Upload Ivr Greeting File
*PhonespeakApi.TeamApi* | [**teamUploadMusicOnHold**](docs/TeamApi.md#teamUploadMusicOnHold) | **POST** /client/Team/{id}/MusicOnHold | Upload MusicOnHold File
*PhonespeakApi.TeamApi* | [**teamUploadVoicemailGreeting**](docs/TeamApi.md#teamUploadVoicemailGreeting) | **POST** /client/Team/{id}/VoicemailGreeting | Upload Voicemail Greeting File
*PhonespeakApi.TeammateApi* | [**teammateAddDnd**](docs/TeammateApi.md#teammateAddDnd) | **POST** /client/Teammate/{id}/Dnd | Add Dnd Team
*PhonespeakApi.TeammateApi* | [**teammateAddPhoneNumber**](docs/TeammateApi.md#teammateAddPhoneNumber) | **POST** /client/Teammate/{id}/PhoneNumber | Add Phone Number
*PhonespeakApi.TeammateApi* | [**teammateAuthenticate**](docs/TeammateApi.md#teammateAuthenticate) | **POST** /client/Teammate/{accountId}/Authenticate/{id} | 
*PhonespeakApi.TeammateApi* | [**teammateAvailableContactList**](docs/TeammateApi.md#teammateAvailableContactList) | **GET** /client/Teammate/{id}/AvailableContactList | Get all available number of teammate
*PhonespeakApi.TeammateApi* | [**teammateConvertTextToSpeech**](docs/TeammateApi.md#teammateConvertTextToSpeech) | **POST** /client/Teammate/{id}/VoicemailGreeting/SpeechGreeting | Convert text to speech(voicemail greeting)
*PhonespeakApi.TeammateApi* | [**teammateCreate**](docs/TeammateApi.md#teammateCreate) | **POST** /client/Teammate | Create a single teammate (PreCond : Get and reserve the number to create the teammate)
*PhonespeakApi.TeammateApi* | [**teammateDelete**](docs/TeammateApi.md#teammateDelete) | **DELETE** /client/Teammate/{id} | Delete a single teammate
*PhonespeakApi.TeammateApi* | [**teammateDeletePhoneNumber**](docs/TeammateApi.md#teammateDeletePhoneNumber) | **DELETE** /client/Teammate/{id}/PhoneNumber/{phoneNumberId} | Delete Phone Number
*PhonespeakApi.TeammateApi* | [**teammateDeleteVoicemailGreeting**](docs/TeammateApi.md#teammateDeleteVoicemailGreeting) | **DELETE** /client/Teammate/{id}/VoicemailGreeting/{voicemailId} | Delete voicemail greeting
*PhonespeakApi.TeammateApi* | [**teammateDummyEndpointAvailableContactList**](docs/TeammateApi.md#teammateDummyEndpointAvailableContactList) | **GET** /client/Teammate/{id}/AvailableContactList/DummyEndpoint | Get all available number of teammate (Dummy Endpoint)
*PhonespeakApi.TeammateApi* | [**teammateGet**](docs/TeammateApi.md#teammateGet) | **GET** /client/Teammate/{id} | Retrieve a single teammate
*PhonespeakApi.TeammateApi* | [**teammateGetTeammateEmail**](docs/TeammateApi.md#teammateGetTeammateEmail) | **GET** /client/Teammate/GetTeammateEmail | Check email is exist
*PhonespeakApi.TeammateApi* | [**teammateList**](docs/TeammateApi.md#teammateList) | **GET** /client/Teammate | Get all teammates
*PhonespeakApi.TeammateApi* | [**teammateListAvailableUseNumber**](docs/TeammateApi.md#teammateListAvailableUseNumber) | **GET** /client/Teammate/{id}/AvailableUseNumber | List Caller Id
*PhonespeakApi.TeammateApi* | [**teammateListVoicemailGreetings**](docs/TeammateApi.md#teammateListVoicemailGreetings) | **GET** /client/Teammate/{id}/VoicemailGreeting | Get list  of voicemail greetings
*PhonespeakApi.TeammateApi* | [**teammateLogin**](docs/TeammateApi.md#teammateLogin) | **POST** /client/Teammate/Login | Login
*PhonespeakApi.TeammateApi* | [**teammateLoginImpersonate**](docs/TeammateApi.md#teammateLoginImpersonate) | **POST** /client/Teammate/{accountId}/Impersonate/{id} | Impersonate login
*PhonespeakApi.TeammateApi* | [**teammateNewPassword**](docs/TeammateApi.md#teammateNewPassword) | **PUT** /client/Teammate/{id}/NewPassword | Login and change password.
*PhonespeakApi.TeammateApi* | [**teammateProcessOnBoarding**](docs/TeammateApi.md#teammateProcessOnBoarding) | **PUT** /client/Teammate/{id}/ProcessOnBoarding | On boarding for first time teammate (included create extension)
*PhonespeakApi.TeammateApi* | [**teammateRemoveDnd**](docs/TeammateApi.md#teammateRemoveDnd) | **DELETE** /client/Teammate/{id}/Dnd | Remove Dnd Team
*PhonespeakApi.TeammateApi* | [**teammateResendActivation**](docs/TeammateApi.md#teammateResendActivation) | **POST** /client/Teammate/{id}/Activation | Resend activation email
*PhonespeakApi.TeammateApi* | [**teammateResetPassword**](docs/TeammateApi.md#teammateResetPassword) | **POST** /client/Teammate/ResetPassword | Forgot password
*PhonespeakApi.TeammateApi* | [**teammateResetPassword_0**](docs/TeammateApi.md#teammateResetPassword_0) | **POST** /client/Teammate/{id}/ResetPassword | Admin reset teammate&#39;s password
*PhonespeakApi.TeammateApi* | [**teammateSearchContact**](docs/TeammateApi.md#teammateSearchContact) | **GET** /client/Teammate/{teammateId}/SearchContact | List contact by teammate
*PhonespeakApi.TeammateApi* | [**teammateSearchMessage**](docs/TeammateApi.md#teammateSearchMessage) | **GET** /client/Teammate/{teammateId}/SearchMessage | List message by teammate
*PhonespeakApi.TeammateApi* | [**teammateUnreadCount**](docs/TeammateApi.md#teammateUnreadCount) | **GET** /client/Teammate/{id}/UnreadCount | Total Unread
*PhonespeakApi.TeammateApi* | [**teammateUpdate**](docs/TeammateApi.md#teammateUpdate) | **PUT** /client/Teammate/{id} | Update details
*PhonespeakApi.TeammateApi* | [**teammateUpdateBusinessHour**](docs/TeammateApi.md#teammateUpdateBusinessHour) | **PUT** /client/Teammate/{id}/BusinessHour | Update business hour
*PhonespeakApi.TeammateApi* | [**teammateUpdateCallRecording**](docs/TeammateApi.md#teammateUpdateCallRecording) | **PUT** /client/Teammate/{id}/CallRecording | Update voicemail pin
*PhonespeakApi.TeammateApi* | [**teammateUpdateCallWaiting**](docs/TeammateApi.md#teammateUpdateCallWaiting) | **PUT** /client/Teammate/{id}/CallWaiting | Update call waiting setting
*PhonespeakApi.TeammateApi* | [**teammateUpdateChangePasswordStatus**](docs/TeammateApi.md#teammateUpdateChangePasswordStatus) | **PUT** /client/Teammate/{id}/ChangePasswordStatus | Update change password status (required to change the password after login.)
*PhonespeakApi.TeammateApi* | [**teammateUpdateDefaultCallerId**](docs/TeammateApi.md#teammateUpdateDefaultCallerId) | **PUT** /client/Teammate/{id}/CallerId/{phoneNumberId} | Update default Caller Id
*PhonespeakApi.TeammateApi* | [**teammateUpdateE911Address**](docs/TeammateApi.md#teammateUpdateE911Address) | **PUT** /client/Teammate/{id}/E911Address | Update E911 address
*PhonespeakApi.TeammateApi* | [**teammateUpdateE911AddressList**](docs/TeammateApi.md#teammateUpdateE911AddressList) | **PUT** /client/Teammate/{id}/E911AddressList | Update E911 address List
*PhonespeakApi.TeammateApi* | [**teammateUpdateEmail**](docs/TeammateApi.md#teammateUpdateEmail) | **PUT** /client/Teammate/{id}/Email | Update email
*PhonespeakApi.TeammateApi* | [**teammateUpdateMissedCallHandling**](docs/TeammateApi.md#teammateUpdateMissedCallHandling) | **PUT** /client/Teammate/{id}/MissedCallHandling | Update miss call handling
*PhonespeakApi.TeammateApi* | [**teammateUpdateOnboardingStatus**](docs/TeammateApi.md#teammateUpdateOnboardingStatus) | **PUT** /client/Teammate/{id}/OnboardingStatus | Update onboarding status (required to go through on boarding process after login)
*PhonespeakApi.TeammateApi* | [**teammateUpdateOnlineStatus**](docs/TeammateApi.md#teammateUpdateOnlineStatus) | **PUT** /client/Teammate/{id}/OnlineStatus | Update online status
*PhonespeakApi.TeammateApi* | [**teammateUpdatePassword**](docs/TeammateApi.md#teammateUpdatePassword) | **PUT** /client/Teammate/{id}/UpdatePassword | Teammate update self password
*PhonespeakApi.TeammateApi* | [**teammateUpdatePbxOnlineStatus**](docs/TeammateApi.md#teammateUpdatePbxOnlineStatus) | **PUT** /client/Teammate/{id}/PbxOnlineStatus | Update Pbx online status
*PhonespeakApi.TeammateApi* | [**teammateUpdatePhoneNumber**](docs/TeammateApi.md#teammateUpdatePhoneNumber) | **PUT** /client/Teammate/{id}/PhoneNumber/{phoneNumberId} | Update Phone Number
*PhonespeakApi.TeammateApi* | [**teammateUpdateSelectedVoicemailGreeting**](docs/TeammateApi.md#teammateUpdateSelectedVoicemailGreeting) | **PUT** /client/Teammate/{id}/VoicemailGreeting/{voicemailId} | Set voicemail greeting
*PhonespeakApi.TeammateApi* | [**teammateUpdateStatus**](docs/TeammateApi.md#teammateUpdateStatus) | **PUT** /client/Teammate/{id}/Status | Update status
*PhonespeakApi.TeammateApi* | [**teammateUpdateVoicemailPin**](docs/TeammateApi.md#teammateUpdateVoicemailPin) | **PUT** /client/Teammate/{id}/VoicemailPin | Update voicemail pin
*PhonespeakApi.TeammateApi* | [**teammateUploadProfileImage**](docs/TeammateApi.md#teammateUploadProfileImage) | **POST** /client/Teammate/{id}/ProfileImage | Upload profile image (format-accepted: .gif |.jpg |.jpeg |.png)
*PhonespeakApi.TeammateApi* | [**teammateUploadVoicemailGreeting**](docs/TeammateApi.md#teammateUploadVoicemailGreeting) | **POST** /client/Teammate/{id}/VoicemailGreeting | Upload voicemail greeting
*PhonespeakApi.VoicemailApi* | [**voicemailDelete**](docs/VoicemailApi.md#voicemailDelete) | **DELETE** /client/Voicemail/{id} | Delete a single voicemail
*PhonespeakApi.VoicemailApi* | [**voicemailList**](docs/VoicemailApi.md#voicemailList) | **GET** /client/Voicemail/{ownerId} | List all voicemails by owner id
*PhonespeakApi.VoicemailApi* | [**voicemailListDummyEndPoint**](docs/VoicemailApi.md#voicemailListDummyEndPoint) | **GET** /client/Voicemail/{ownerId}/dummyendpoint | List all voicemails by owner id
*PhonespeakApi.VoicemailApi* | [**voicemailUnreadVoicemailCount**](docs/VoicemailApi.md#voicemailUnreadVoicemailCount) | **GET** /client/Voicemail/{id}/UnreadCount | Total Unread Voicemail
*PhonespeakApi.VoicemailApi* | [**voicemailUpdateAllVoicemailReadStatus**](docs/VoicemailApi.md#voicemailUpdateAllVoicemailReadStatus) | **PUT** /client/Voicemail/{ownerId}/Read | Update all voicemail read status
*PhonespeakApi.VoicemailApi* | [**voicemailUpdateVoicemailReadStatus**](docs/VoicemailApi.md#voicemailUpdateVoicemailReadStatus) | **PUT** /client/Voicemail/{ownerId}/Read/{id} | Update voicemail read status
*PhonespeakApi.VoicemailApi* | [**voicemailUpdateVoicemailUnreadStatus**](docs/VoicemailApi.md#voicemailUpdateVoicemailUnreadStatus) | **PUT** /client/Voicemail/{ownerId}/Unread/{id} | Update voicemail unread status


## Documentation for Models

 - [PhonespeakApi.Account](docs/Account.md)
 - [PhonespeakApi.AccountCurrentExtension](docs/AccountCurrentExtension.md)
 - [PhonespeakApi.AccountSetting](docs/AccountSetting.md)
 - [PhonespeakApi.AddCompanyNumberInfo](docs/AddCompanyNumberInfo.md)
 - [PhonespeakApi.AddTeammateInfo](docs/AddTeammateInfo.md)
 - [PhonespeakApi.Address](docs/Address.md)
 - [PhonespeakApi.Authentication](docs/Authentication.md)
 - [PhonespeakApi.AvailableNumber](docs/AvailableNumber.md)
 - [PhonespeakApi.BandwidthPortin](docs/BandwidthPortin.md)
 - [PhonespeakApi.BandwidthPortinSearch](docs/BandwidthPortinSearch.md)
 - [PhonespeakApi.BillingAddress](docs/BillingAddress.md)
 - [PhonespeakApi.BillingContact](docs/BillingContact.md)
 - [PhonespeakApi.BusinessHour](docs/BusinessHour.md)
 - [PhonespeakApi.CallHandlingClosedHour](docs/CallHandlingClosedHour.md)
 - [PhonespeakApi.CallHandlingOpenHour](docs/CallHandlingOpenHour.md)
 - [PhonespeakApi.CallLog](docs/CallLog.md)
 - [PhonespeakApi.CallQueue](docs/CallQueue.md)
 - [PhonespeakApi.CallRecording](docs/CallRecording.md)
 - [PhonespeakApi.CallTarget](docs/CallTarget.md)
 - [PhonespeakApi.Cart](docs/Cart.md)
 - [PhonespeakApi.Cdr](docs/Cdr.md)
 - [PhonespeakApi.Charges](docs/Charges.md)
 - [PhonespeakApi.ChatFile](docs/ChatFile.md)
 - [PhonespeakApi.CompanyNumber](docs/CompanyNumber.md)
 - [PhonespeakApi.Contact](docs/Contact.md)
 - [PhonespeakApi.Conversation](docs/Conversation.md)
 - [PhonespeakApi.Country](docs/Country.md)
 - [PhonespeakApi.CouponDetail](docs/CouponDetail.md)
 - [PhonespeakApi.CreateConversation](docs/CreateConversation.md)
 - [PhonespeakApi.CreditCard](docs/CreditCard.md)
 - [PhonespeakApi.CspFetchMessageRequest](docs/CspFetchMessageRequest.md)
 - [PhonespeakApi.CspPushToken](docs/CspPushToken.md)
 - [PhonespeakApi.CspSendMessage](docs/CspSendMessage.md)
 - [PhonespeakApi.CsrAccount](docs/CsrAccount.md)
 - [PhonespeakApi.CsrUser](docs/CsrUser.md)
 - [PhonespeakApi.DeskphoneMacAddress](docs/DeskphoneMacAddress.md)
 - [PhonespeakApi.E911](docs/E911.md)
 - [PhonespeakApi.E911Address](docs/E911Address.md)
 - [PhonespeakApi.EmailTemplate](docs/EmailTemplate.md)
 - [PhonespeakApi.GLog](docs/GLog.md)
 - [PhonespeakApi.GetNumber](docs/GetNumber.md)
 - [PhonespeakApi.Greeting](docs/Greeting.md)
 - [PhonespeakApi.IncomingMessage](docs/IncomingMessage.md)
 - [PhonespeakApi.InlineResponse200](docs/InlineResponse200.md)
 - [PhonespeakApi.InteliquentSMSInbound](docs/InteliquentSMSInbound.md)
 - [PhonespeakApi.Invoice](docs/Invoice.md)
 - [PhonespeakApi.InvoiceItem](docs/InvoiceItem.md)
 - [PhonespeakApi.Item](docs/Item.md)
 - [PhonespeakApi.Ivr](docs/Ivr.md)
 - [PhonespeakApi.IvrKey](docs/IvrKey.md)
 - [PhonespeakApi.IvrTimeOut](docs/IvrTimeOut.md)
 - [PhonespeakApi.LastLogin](docs/LastLogin.md)
 - [PhonespeakApi.Message](docs/Message.md)
 - [PhonespeakApi.MessageDetail](docs/MessageDetail.md)
 - [PhonespeakApi.MissedCallHandling](docs/MissedCallHandling.md)
 - [PhonespeakApi.ModelPackage](docs/ModelPackage.md)
 - [PhonespeakApi.MusicOnHold](docs/MusicOnHold.md)
 - [PhonespeakApi.Order](docs/Order.md)
 - [PhonespeakApi.OrderPaymentInfo](docs/OrderPaymentInfo.md)
 - [PhonespeakApi.PbxCallStatus](docs/PbxCallStatus.md)
 - [PhonespeakApi.PhoneNumber](docs/PhoneNumber.md)
 - [PhonespeakApi.Product](docs/Product.md)
 - [PhonespeakApi.ProfileImage](docs/ProfileImage.md)
 - [PhonespeakApi.RateDeck](docs/RateDeck.md)
 - [PhonespeakApi.ReserveNumber](docs/ReserveNumber.md)
 - [PhonespeakApi.ResetPasswordOption](docs/ResetPasswordOption.md)
 - [PhonespeakApi.RingGroup](docs/RingGroup.md)
 - [PhonespeakApi.SMSHandling](docs/SMSHandling.md)
 - [PhonespeakApi.ShippingInfo](docs/ShippingInfo.md)
 - [PhonespeakApi.SignupInfo](docs/SignupInfo.md)
 - [PhonespeakApi.SmsInbound](docs/SmsInbound.md)
 - [PhonespeakApi.StripeCharge](docs/StripeCharge.md)
 - [PhonespeakApi.StripeInfo](docs/StripeInfo.md)
 - [PhonespeakApi.SupportEmail](docs/SupportEmail.md)
 - [PhonespeakApi.Team](docs/Team.md)
 - [PhonespeakApi.Teammate](docs/Teammate.md)
 - [PhonespeakApi.TextToSpeechInfo](docs/TextToSpeechInfo.md)
 - [PhonespeakApi.TrackingRequest](docs/TrackingRequest.md)
 - [PhonespeakApi.Url](docs/Url.md)
 - [PhonespeakApi.Voicemail](docs/Voicemail.md)


## Documentation for Authorization


### Authorization

- **Type**: API key
- **API key parameter name**: Authorization
- **Location**: HTTP header

