# PhonespeakApi.EmailApi

All URIs are relative to *http://api-dev.phonespeak.com*

Method | HTTP request | Description
------------- | ------------- | -------------
[**emailCreate**](EmailApi.md#emailCreate) | **POST** /client/Email/Create | Create a single email template
[**emailDelete**](EmailApi.md#emailDelete) | **DELETE** /client/Email/{templateid}/Delete | Delete email template
[**emailGet**](EmailApi.md#emailGet) | **GET** /client/Email/{templateid}/Get | Retrieve a single email template by id
[**emailList**](EmailApi.md#emailList) | **GET** /client/Email/List | Retrieve list of email templates
[**emailUpdate**](EmailApi.md#emailUpdate) | **PUT** /client/Email/{id}/Update | Update a single email template


<a name="emailCreate"></a>
# **emailCreate**
> Object emailCreate(emailTemplate)

Create a single email template

### Example
```javascript
var PhonespeakApi = require('phonespeak_api');
var defaultClient = PhonespeakApi.ApiClient.instance;

// Configure API key authorization: Authorization
var Authorization = defaultClient.authentications['Authorization'];
Authorization.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//Authorization.apiKeyPrefix = 'Token';

var apiInstance = new PhonespeakApi.EmailApi();

var emailTemplate = new PhonespeakApi.EmailTemplate(); // EmailTemplate | The email template object


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
apiInstance.emailCreate(emailTemplate, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **emailTemplate** | [**EmailTemplate**](EmailTemplate.md)| The email template object | 

### Return type

**Object**

### Authorization

[Authorization](../README.md#Authorization)

### HTTP request headers

 - **Content-Type**: application/json, application/xml
 - **Accept**: application/json, application/xml

<a name="emailDelete"></a>
# **emailDelete**
> Object emailDelete(templateid)

Delete email template

### Example
```javascript
var PhonespeakApi = require('phonespeak_api');
var defaultClient = PhonespeakApi.ApiClient.instance;

// Configure API key authorization: Authorization
var Authorization = defaultClient.authentications['Authorization'];
Authorization.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//Authorization.apiKeyPrefix = 'Token';

var apiInstance = new PhonespeakApi.EmailApi();

var templateid = "templateid_example"; // String | The email template id to delete


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
apiInstance.emailDelete(templateid, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **templateid** | **String**| The email template id to delete | 

### Return type

**Object**

### Authorization

[Authorization](../README.md#Authorization)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json, application/xml

<a name="emailGet"></a>
# **emailGet**
> Object emailGet(templateid)

Retrieve a single email template by id

### Example
```javascript
var PhonespeakApi = require('phonespeak_api');
var defaultClient = PhonespeakApi.ApiClient.instance;

// Configure API key authorization: Authorization
var Authorization = defaultClient.authentications['Authorization'];
Authorization.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//Authorization.apiKeyPrefix = 'Token';

var apiInstance = new PhonespeakApi.EmailApi();

var templateid = "templateid_example"; // String | The email template id to retrieve


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
apiInstance.emailGet(templateid, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **templateid** | **String**| The email template id to retrieve | 

### Return type

**Object**

### Authorization

[Authorization](../README.md#Authorization)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json, application/xml

<a name="emailList"></a>
# **emailList**
> Object emailList(opts)

Retrieve list of email templates

### Example
```javascript
var PhonespeakApi = require('phonespeak_api');
var defaultClient = PhonespeakApi.ApiClient.instance;

// Configure API key authorization: Authorization
var Authorization = defaultClient.authentications['Authorization'];
Authorization.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//Authorization.apiKeyPrefix = 'Token';

var apiInstance = new PhonespeakApi.EmailApi();

var opts = { 
  'size': 56, // Number | Number of records to retrieve (optional)
  'pageNum': 56 // Number | Page number to retrieve (optional)
};

var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
apiInstance.emailList(opts, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **size** | **Number**| Number of records to retrieve (optional) | [optional] 
 **pageNum** | **Number**| Page number to retrieve (optional) | [optional] 

### Return type

**Object**

### Authorization

[Authorization](../README.md#Authorization)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json, application/xml

<a name="emailUpdate"></a>
# **emailUpdate**
> Object emailUpdate(id, emailTemplate)

Update a single email template

### Example
```javascript
var PhonespeakApi = require('phonespeak_api');
var defaultClient = PhonespeakApi.ApiClient.instance;

// Configure API key authorization: Authorization
var Authorization = defaultClient.authentications['Authorization'];
Authorization.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//Authorization.apiKeyPrefix = 'Token';

var apiInstance = new PhonespeakApi.EmailApi();

var id = "id_example"; // String | template id

var emailTemplate = new PhonespeakApi.EmailTemplate(); // EmailTemplate | The email template object to update


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
apiInstance.emailUpdate(id, emailTemplate, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **String**| template id | 
 **emailTemplate** | [**EmailTemplate**](EmailTemplate.md)| The email template object to update | 

### Return type

**Object**

### Authorization

[Authorization](../README.md#Authorization)

### HTTP request headers

 - **Content-Type**: application/json, application/xml
 - **Accept**: application/json, application/xml

